@@ -7,30 +7,109 @@ test_that("test it works", {
                  includeHeaderName = TRUE)
   gt <- formatTable(result)
   expect_true("gt_tbl" %in% class(gt))
-  # check correct style:
-  expect_equal(unlist(gt$`_styles`$styles[gt$`_styles`$locname == "columns_columns"])[1:27] |> unique(),
-               c("#E1E1E1", "center", "bold"))
-  expect_equal(unlist(gt$`_styles`$styles[gt$`_styles`$locname == "columns_columns"])[28:43] |> unique(),
-               c("center", "bold"))
-  expect_false(lapply(gt$`_boxhead`$column_label, function(x){grepl("\\[header_level\\]", x)}) |> unlist() |> unique())
-  expect_equal(gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level %in% c(1,3)]] |>
-                 unlist() |> unique(),
-               c("#D9D9D9", "center", "bold"))
-  expect_equal(gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level == 2]] |>
-                 unlist() |> unique(),
-               c("#E1E1E1", "center", "bold"))
-  expect_equal(gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level == 4]] |>
-                 unlist() |> unique(),
-               c("#C8C8C8", "center", "bold"))
+
+  # check style of columns_columns
+  styleColumns <- gt$`_styles`$styles[gt$`_styles`$locname == "columns_columns"]
+
+  # style of the last 9 cells
+  # background color
+  backgroundColor <- styleColumns[1:9] |>
+    purrr::map_chr(\(x) x$cell_fill$color) |>
+    unique()
+  expect_identical("#E1E1E1", backgroundColor)
+  # align center
+  align <- styleColumns[1:9] |>
+    purrr::map_chr(\(x) x$cell_text$align) |>
+    unique()
+  expect_identical("center", align)
+  # bold text
+  weight <- styleColumns[1:9] |>
+    purrr::map_chr(\(x) x$cell_text$weight) |>
+    unique()
+  expect_identical("bold", weight)
+
+  # style of the other cells
+  # align center
+  align <- styleColumns[10:19] |>
+    purrr::map_chr(\(x) x$cell_text$align) |>
+    unique()
+  expect_identical("center", align)
+  # bold text
+  weight <- styleColumns[10:19] |>
+    purrr::map_chr(\(x) x$cell_text$weight) |>
+    unique()
+  expect_identical("bold", weight)
+
+  # expect no header_level in header
+  headerLevel <- gt$`_boxhead`$column_label |>
+    unlist() |>
+    purrr::keep(\(x) grepl(pattern = "\\[header_level\\]", x = x))
+  expect_true(length(headerLevel) == 0)
+
+  # check style of the spanners
+
+  # spanners 1 and 3
+  styleColumns <- gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level %in% c(1,3)]]
+  # background color
+  backgroundColor <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_fill$color) |>
+    unique()
+  expect_identical("#D9D9D9", backgroundColor)
+  # align center
+  align <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$align) |>
+    unique()
+  expect_identical("center", align)
+  # bold text
+  weight <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$weight) |>
+    unique()
+  expect_identical("bold", weight)
+
+  # spanner 2
+  styleColumns <- gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level == 2]]
+  # background color
+  backgroundColor <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_fill$color) |>
+    unique()
+  expect_identical("#E1E1E1", backgroundColor)
+  # align center
+  align <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$align) |>
+    unique()
+  expect_identical("center", align)
+  # bold text
+  weight <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$weight) |>
+    unique()
+  expect_identical("bold", weight)
+
+  # spanner 4
+  styleColumns <- gt$`_styles`$styles[gt$`_styles`$grpname %in% gt$`_spanners`$spanner_id[gt$`_spanners`$spanner_level == 4]]
+  # background color
+  backgroundColor <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_fill$color) |>
+    unique()
+  expect_identical("#C8C8C8", backgroundColor)
+  # align center
+  align <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$align) |>
+    unique()
+  expect_identical("center", align)
+  # bold text
+  weight <- styleColumns |>
+    purrr::map_chr(\(x) x$cell_text$weight) |>
+    unique()
+  expect_identical("bold", weight)
 
   fx <- formatTable(result, type = "flextable")
   expect_true("flextable" %in% class(fx))
   # Spanner styles
   header_col_style <- fx$header$styles$cells$background.color$data[, "strata\nstrata_name\noverall\nstrata_level\noverall"]
   expect_equal(header_col_style, c("#c8c8c8", "#d9d9d9", "#e1e1e1", "#d9d9d9", "#e1e1e1"))
-  expect_equal(fx$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "transparent")
-  expect_equal(fx$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(0.8, 1))
-  expect_equal(fx$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "gray")
+  expect_equal(fx$header$styles$cells$background.color$data[, "cdm_name"] |> unique(), "#e1e1e1")
+  expect_equal(fx$header$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), c(1))
+  expect_equal(fx$header$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "#c8c8c8")
   expect_true(fx$header$styles$text$bold$data[, "cdm_name"] |> unique())
   expect_equal(fx$header$styles$text$color$data[, "cdm_name"] |> unique(), "black")
   expect_equal(fx$header$styles$text$color$data[, "cdm_name"] |> unique(), "black")
@@ -38,7 +117,7 @@ test_that("test it works", {
 
   # body
   expect_equal(fx$body$styles$cells$border.width.top$data[, "cdm_name"] |> unique(), 1)
-  expect_equal(fx$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "gray")
+  expect_equal(fx$body$styles$cells$border.color.left$data[, "cdm_name"] |> unique(), "#c8c8c8")
   expect_equal(fx$body$styles$cells$background.color$data[, "cdm_name"],
                c("transparent", "transparent", "transparent", "transparent","transparent",
                  "transparent", "transparent", "transparent", "transparent", "transparent"))
@@ -52,7 +131,14 @@ test_that("test it works", {
   expect_error(formatTable(result, subtitle = "subtitle"))
 
   res <- formatTable(x = result, type = "tibble")
-  expect_identical(res, result)
+  expect_identical(
+    res,
+    result |>
+      dplyr::mutate(
+        dplyr::across(dplyr::where(~ is.numeric(.x)), ~ as.character(.x)),
+        dplyr::across(colnames(result), ~ dplyr::if_else(is.na(.x), "\u2013", .x))
+      )
+  )
 })
 
 test_that("datatable works", {
@@ -87,8 +173,11 @@ test_that("reactable works", {
   dt <- formatTable(result, type = "reactable")
   expect_snapshot(dt$x)
 
-  dt <- formatTable(result, type = "reactable", style = list("outlined" = TRUE,
-                    "bordered" = TRUE, defaultSorted = "Male"), delim = "\n")
+
+  dt <- formatTable(result,
+                    type = "reactable",
+                    style = list("outlined" = TRUE, "bordered" = TRUE, defaultSorted = "Male"),
+                    delim = "\n")
   expect_snapshot(dt$x)
 
   dt <- formatTable(result, type = "reactable", groupColumn = "group_level", delim = ".")
